@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-adblock-extension.c 1671 2008-02-17 18:21:45Z xan $
+ *  $Id$
  */
 
 #include "config.h"
@@ -37,14 +37,7 @@
 #include "ad-uri-tester.h"
 #include "adblock-ui.h"
 
-#include <gtk/gtkaction.h>
-#include <gtk/gtkactiongroup.h>
-#include <gtk/gtkeventbox.h>
-#include <gtk/gtkiconfactory.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtknotebook.h>
-#include <gtk/gtkuimanager.h>
-#include <gtk/gtkstock.h>
+#include <gtk/gtk.h>
 
 #include <gmodule.h>
 
